==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/fr/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Plus d'info",

    "audit_help" => "Cocher cette case va modifier l'enregistrement de la ressource pour refléter ce nouvel emplacement. Laisser décoché notera simplement l'emplacement dans le journal d'audit.<br><br>Notez que cette ressource est vérifiée, elle ne changera pas l'emplacement de la personne, de la ressource ou de l'emplacement où elle est vérifiée.",

    'assets' => 'Les actifs sont des éléments suivis par le numéro de série ou la balise d\'actif. Ils ont tendance à être des éléments de valeur plus élevée lorsque l\'identification d\'un élément spécifique importe.',

    'categories' => 'Les catégories vous aident à organiser vos articles. Des catégories d\'exemples peuvent être &quot;des ordinateurs de bureau&quot;, &quot;des ordinateurs portables&quot;, &quot;des téléphones mobiles&quot;, &quot;des tablettes&quot;, et ainsi de suite, mais vous pouvez librement utiliser des catégories qui ont du sens pour vous.',

    'accessories' => 'Les accessoires sont tout ce que vous envoyez aux utilisateurs, mais qui n\'ont pas de numéro de série (ou vous n\'avez pas à les suivre de façon unique). Par exemple, souris ou claviers.',

    'companies'     => 'Les sociétés peuvent être utilisées comme simple champ d\'identification, ou bien afin de limité la visibilité des matériels, utilisateurs etc... Si le support complet de la société est activé dans les paramètres d\'administration.',

    'components'    => 'Les composants sont des éléments constitutifs d\'un matériel, par exemple HDD, RAM, etc.',

    'consumables'   => 'Les consommables sont tout ce qui est acheté et qui sera utilisé au fil du temps. Par exemple, l\'encre de l\'imprimante ou le papier de copieur.',

    'depreciations' => 'Vous pouvez mettre en place des amortissements d’actifs pour déprécier les matériels en fonction de la dépréciation linéaire.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/fr/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Plus d\'info',

    'audit_help' => 'Cocher cette case va modifier l\'enregistrement de la ressource pour refléter ce nouvel emplacement. Laisser décoché notera simplement l\'emplacement dans le journal d\'audit.<br><br>Notez que cette ressource est vérifiée, elle ne changera pas l\'emplacement de la personne, de la ressource ou de l\'emplacement où elle est vérifiée.',

    'assets' => 'Les actifs sont des éléments suivis par le numéro de série ou la balise d\'actif. Ils ont tendance à être des éléments de valeur plus élevée lorsque l\'identification d\'un élément spécifique importe.',

    'categories' => 'Les catégories vous aident à organiser vos articles. Des catégories d\'exemples peuvent être &quot;des ordinateurs de bureau&quot;, &quot;des ordinateurs portables&quot;, &quot;des téléphones mobiles&quot;, &quot;des tablettes&quot;, et ainsi de suite, mais vous pouvez librement utiliser des catégories qui ont du sens pour vous.',

    'accessories' => 'Les accessoires sont tout ce que vous envoyez aux utilisateurs, mais qui n\'ont pas de numéro de série (ou vous n\'avez pas à les suivre de façon unique). Par exemple, souris ou claviers.',

    'companies'     => 'Les sociétés peuvent être utilisées comme simple champ d\'identification, ou bien afin de limité la visibilité des matériels, utilisateurs etc... Si le support complet de la société est activé dans les paramètres d\'administration.',

    'components'    => 'Les composants sont des éléments constitutifs d\'un matériel, par exemple HDD, RAM, etc.',

    'consumables'   => 'Les consommables sont tout ce qui est acheté et qui sera utilisé au fil du temps. Par exemple, l\'encre de l\'imprimante ou le papier de copieur.',

    'depreciations' => 'Vous pouvez mettre en place des amortissements d’actifs pour déprécier les matériels en fonction de la dépréciation linéaire.',

];
